@@ -50,18 +50,29 @@ def clean_project_name(projectName):
     projectName = projectName.replace('-', '_')
     return projectName
 def create_project(projectName):
-    create_folder(projectName)
+    create_folders(projectName)
     create_pipeline_file(projectName, 'preprocessor')
     create_pipeline_file(projectName, 'postprocessor')
     create_pipeline_file(projectName, 'labelizer')
     create_pipeline_file(projectName, 'pipeline')
 
-def create_folder(projectName):
+
+    create_testet_file(projectName, 'dataset')
+    create_testet_file(projectName, 'reporter')
+    create_testet_file(projectName, 'tester')
+    create_testet_file(projectName, 'tester_server')
+
+def create_folders(projectName):
     global directory
     directory = projectName + '_pipeline'
     if not os.path.exists(directory):
         os.mkdir(directory)
 
+    global tester_directory
+    tester_directory = directory + '/tester/'
+    if not os.path.exists(tester_directory):
+        os.mkdir(tester_directory)
+
 def create_pipeline_file(projectName, pipelineType):
     with open(os.path.join(__location__, 'cli/' + pipelineType + '_template.py'), 'r') as file:
         data = file.read()
@@ -84,11 +95,37 @@ def create_pipeline_file(projectName, pipelineType):
             f.close()
         create_pipeline_init_file(new_init_file, new_init_export)
 
+def create_testet_file(projectName, pipelineType):
+    with open(os.path.join(__location__, 'cli/tester/' + pipelineType + '_template.py'), 'r') as file:
+        data = file.read()
+        projectNameNoUnderscore = ''.join(elem.capitalize() for elem in projectName.split('_'))
+        className = projectNameNoUnderscore + pipelineType.capitalize()
+        classNameFotBaseObject = projectNameNoUnderscore + '_' + pipelineType
+        data = data.replace('generatedClassName', classNameFotBaseObject)
+        data = data.replace('generatedClass',className)
+        data = data.replace('generatedProjectName',projectNameNoUnderscore)
+        data = data.replace('generatedDirectory',directory)
+        current_dir = tester_directory
+        new_file = current_dir + "/" + pipelineType + ".py"
+        new_init_file = current_dir + "/__init__.py"
+        new_init_export = "from " + tester_directory.replace('/', '.') + pipelineType + " import " + className
+        if not os.path.exists(new_file):
+            f = open(new_file, "w")
+            f.write(data)
+            f.close()
+        create_tester_init_file(new_init_file, new_init_export)
+
 def create_pipeline_init_file(init_path, init_export):
     if not os.path.exists(init_path):
         f = open(init_path, "w")
         f.write(init_export)
         f.close()
 
+def create_tester_init_file(init_path, init_export):
+    f = open(init_path, "a")
+    f.write(init_export)
+    f.write("\n")
+    f.close()
+
 if __name__ == '__main__':
     cli(prog_name='cli')
